==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation type="unfinished">Bildinformation</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Denna filen innehåller flera sidor, vänligen använd Evince för att se alla sidor.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation type="vanished">Öppna katalog</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Du saknar rättigheter för att visa bilden</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Avbryt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Radera</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Ändringsdatum</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="vanished">Dimensioner</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Filstorlek</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Fotodatum</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exponeringsläge</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exponeringsprogram</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exponeringstid</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blixt</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Bländaröppning</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brännvidd</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max bländaröppning</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Ljusmätningsmetod</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Vitbalans</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blixtkompensering</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linsmodell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Färgrymd</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramodell</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Ingen skalning</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Anpassa sida efter bild</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Anpassa bild efter sida</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skala till:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Tum</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Bild position</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Skalning</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Bild inställningar</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="vanished">Bild inställningar</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Välj mapp</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Synkronisering är inaktiverad för denna mapp</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Lägg till mapp</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Avbryt synkronisering</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Enheten har tagits bort</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Denna mappen finns ej längre</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Beräknar...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Bildvisare</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Bildspel</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Avsluta bildspel</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Ta bort från album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Ta bort favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotera medurs</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotera moturs</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ange som bakgrundsbild</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visa i filhanteraren</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Föregående skärm</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Nästa skärm</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nytt album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ändra namn</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visa genvägar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Avsluta fullskärm</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation type="vanished">Var god skriv in en ny genväg</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">Genvägar</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation type="vanished">Visa bild</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="vanished">Återställ förval</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="vanished">Visa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Fullskärm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Bildspel</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="vanished">Avsluta bildspel</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="vanished">Skriv ut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopiera</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">Ta bort från album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">Ta bort favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Rotera medurs</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Rotera moturs</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Ange som bakgrundsbild</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Visa i filhanteraren</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="vanished">Bildinformation</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="vanished">Nytt album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">Ändra namn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Radera</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="vanished">Bildspelsinställningar</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation type="vanished">Växlingseffekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">Längd</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="vanished">Växlingslängd</translation>
    </message>
    <message>
        <source>second</source>
        <translation type="vanished">sekund</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation type="unfinished">Min favorit</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Föregående</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Nästa</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished">1:1 Storlek</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished">Anpassa till fönster</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Rotera moturs</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Rotera medurs</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Radera</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Tillbaka</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Bildhantering</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Min favorit</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Storlek</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Anpassa till fönster</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotera moturs</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotera medurs</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Ta bort favorit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Inga bilder hittades</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Öppna bild</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="vanished">Bildspelsinställningar</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation type="vanished">Effekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">Längd</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">Genvägar</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Visa</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation type="vanished">Nytt album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Inställningar</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Tidslinje</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Lägg till i album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Lägg till i nytt album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Avsluta fullskärm</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Bildspel</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Skriv ut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Radera från album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Ta bort favorit</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Visa navigeringsfönster</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Göm navigeringsfönster</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotera medurs</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotera moturs</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ange som bakgrundsbild</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visa i filhanteraren</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Öppna bild</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alla bilder</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ändra namn</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.3.orig.tar.xz: deepin-image-viewer-5.9.3/src/translations/deepin-image-viewer_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Öppna bild</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Bildvisare</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Avsluta fullskärm</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Bildspel</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ändra namn</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotera medurs</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotera moturs</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ange som bakgrundsbild</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visa i filhanteraren</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visa genvägar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
